# Code for Life Portal

[![Workflow Status](https://github.com/ocadotechnology/codeforlife-portal/actions/workflows/ci.yml/badge.svg)](https://github.com/ocadotechnology/codeforlife-portal/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/ocadotechnology/codeforlife-portal/branch/master/graph/badge.svg)](https://codecov.io/gh/ocadotechnology/codeforlife-portal)

[Code for Life](https://www.codeforlife.education/) has been developed by Ocado Technology as a **free, open-source** project to inspire the next generation of computer scientists and to help teachers deliver the computing curriculum.

This repository hosts the source code of the [main website](https://www.codeforlife.education/), which includes the registration, log in, teacher and student dashboards, the teaching materials, etc.

We are open to contributors from anywhere around the world. Please read ahead if you'd like to get involved.

## To get started

- [Developer Guide](https://docs.codeforlife.education/developer-guide)

- [Good First Issues](https://github.com/ocadotechnology/codeforlife-portal/contribute)

- [How to set up your work environment](https://docs.codeforlife.education/git/common-setup)

- [Testing](https://docs.codeforlife.education/git/testing)
